@@ -65,6 +65,10 @@ env_code_reader = {"ReaderType": "Cookie", "ReaderKey": "env_code"}
 carrier_header = {"TrackerName": "fast-tracker", "TraceIdName": "x-fast-trace-id"}
 disable_plugins = []  # type: List[str]
 ############################# fast_tracker默认配置信息结束 ###############################
+# 用户自定义user_code、tenant_code、env_code字段值
+custom_user_code = ""
+custom_tenant_code = ""
+custom_env_code = ""
 
 
 def init(
