@@ -118,14 +118,13 @@ def install():
         else:
             code = ""
 
-        if code:
-            # 设置config的code，让其全局适用
-            if type == "tenant_code":
-                config.set_tenant_code(code)
-            elif type == "user_code":
-                config.set_user_code(code)
-            elif type == "env_code":
-                config.set_env_code(code)
+        # 设置用户自定义字段值
+        if type == "tenant_code" and not config.custom_tenant_code:
+            config.custom_tenant_code = code
+        elif type == "user_code" and not config.custom_user_code:
+            config.custom_user_code = code
+        elif type == "env_code" and not config.custom_env_code:
+            config.custom_env_code = code
 
         return code
 
