@@ -38,14 +38,14 @@ def install():
         # 当gunicorn模式启动时，gunicorn会自行上报log信息，也会被此插件拦截，故需剔除gunicorn的log上报 eg：<Logger gunicorn.error (INFO)>
         # uwsgi 不需要拦截，因其无错误log调用
         err_log = this.__str__()
-        if "gunicorn" in err_log:
+        if "gunicorn" in err_log or "kafka" in err_log:
             res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False, stacklevel=1)
 
             return res
 
-        if log_level.get(config.log_level) <= level:
+        if log_level.get(config.logging_level) <= level:
             context = get_context()
-            with context.new_exit_span(op="Log", peer='') as span:
+            with context.new_local_span(op="Log") as span:
                 span.layer = Layer.Local
                 span.component = ComponentType.Log
 
@@ -65,12 +65,12 @@ def install():
         # 当gunicorn模式启动时，gunicorn会自行上报log信息，也会被此插件拦截，故需剔除gunicorn的log上报 eg：<Logger gunicorn.error (INFO)>
         # uwsgi 不需要拦截，因其无错误log调用
         err_log = this.__str__()
-        if "gunicorn" in err_log:
+        if "gunicorn" in err_log or "kafka" in err_log:
             res = _handle(this, level, msg, args, exc_info=None, extra=None, stack_info=False)
 
             return res
 
-        if log_level.get(config.log_level) <= level:
+        if log_level.get(config.logging_level) <= level:
             context = get_context()
             with context.new_exit_span(op="Log", peer='') as span:
                 span.layer = Layer.Local
