@@ -4,6 +4,7 @@
 """
     created by FAST-DEV 2021/4/9
 """
+import threading
 import time
 import sys
 import os
@@ -33,9 +34,7 @@ def log(text, *args, level=1):
     :return:
     """
     startup_debug = os.environ.get("FAST_DEBUG", "off").lower() in ("on", "true", "1")
-    print("FAST_DEBUG:", startup_debug)
     debug_level = int(os.environ.get('FAST_DEBUG_LEVEL', 0))
-    print("FAST_DEBUG_LEVEL:", debug_level)
     if startup_debug:
         if debug_level >= level:
             text = text % args
